@@ -195,6 +195,27 @@ endsWith <- function (x, suffix)
 if (getRversion() < "3.4.0") {
 
 
+print.connection <- .removeSource(evalq(envir = .BaseNamespaceEnv,
+                    function (x, ...)
+{
+    usumm <- tryCatch(unlist(summary(x)), error = function(e) {
+    })
+    if (is.null(usumm)) {
+        cl <- oldClass(x)
+        cl <- cl[cl != "connection"]
+        cat("A connection, ", if (length(cl))
+            paste0("specifically, ", paste(sQuote(cl), collapse = ", "),
+                ", "), "but invalid.\n", sep = "")
+    }
+    else {
+        cat("A connection with")
+        print(cbind(` ` = usumm), ...)
+    }
+    invisible(x)
+}
+))
+
+
 .withAutoprint <- function (exprs, evaluated = FALSE, local = parent.frame(), print. = TRUE,
     echo = TRUE, max.deparse.length = Inf, width.cutoff = max(20, getOption("width")),
     deparseCtrl = c("keepInteger", "showAttributes", "keepNA"),
