@@ -1,6 +1,6 @@
 
 
-# URL.pattern <- "^((?:ftp|ftps|http|https)://[^/]+)(?:/+(.*))?$"
+# URL_pattern <- "^((?:ftp|ftps|http|https)://[^/]+)(?:/+(.*))?$"
 # ##              ^                                            ^ start and end of the string
 # ##                   ^^^^^^^^^^^^^^^^^^^^^^^                   ftp:// or ftps:// or http:// or https://
 # ##                                          ^^^^^              series of non-slash characters
@@ -10,7 +10,7 @@
 # ##                 ^^                              ^^          non-capturing groups
 
 
-# UNC.pattern <- "^(?:(//[^/]+)/+([^/]+))(?:/+(.*))?$"
+# UNC_pattern <- "^(?:(//[^/]+)/+([^/]+))(?:/+(.*))?$"
 # ##              ^                                 ^ start and end of the string
 # ##                   ^^                             two slashes
 # ##                     ^^^^^    ^^^^^               series of non-slash characters, the host and share name
@@ -26,65 +26,79 @@
 # )
 
 
-tmp <- function (x, varname, name)
+check.path <- function (...)
 {
-    varname <- as.symbol(varname)
-    expr <- bquote({
-        expected <- path.join(...)
-        if (!.IS_SCALAR_STR(expected))
-            stop(gettextf("'%s' must be a character string", "expected", domain = "R"))
-        if (!nzchar(expected))
-            stop(gettextf("'%s' must not be \"\"", "expected"))
-        expected <- path.split.1(expected)
-        if (check.wd <- expected[[1L]] == ".")
-            expected <- expected[-1L]
-        ..(x)
-        varname <- path.split.1(varname)
-        if (length(varname) < length(expected) || {
-            i <- seq_along(varname) > length(varname) - length(expected)
-            any(varname[i] != expected)
-        })
-        {
-            expected <- path.unsplit(expected)
-            varname <- path.unsplit(varname[i])
-            stop(msg1,
-                paste0(msg2, {
-                    encodeString(c(varname, expected), quote = "\"")
+    expected <- path.join(...)
+    if (!.IS_SCALAR_STR(expected))
+        stop(gettextf("'%s' must be a character string", "expected", domain = "R"))
+    if (!nzchar(expected))
+        stop(gettextf("'%s' must not be \"\"", "expected"))
+    expected <- path.split.1(expected)
+    if (check_wd <- expected[[1L]] == ".")
+        expected <- expected[-1L]
+    thispath <- .External2(.C_this_path)
+    thispath <- path.split.1(thispath)
+    if (length(thispath) < length(expected) || {
+        i <- seq_along(thispath) > length(thispath) - length(expected)
+        any(thispath[i] != expected)
+    })
+    {
+        expected <- path.unsplit(expected)
+        thispath <- path.unsplit(thispath[i])
+        stop("'this.path()' and expected path do not match\n",
+            paste0(c("* this.path(): ", "* expected   : "), {
+                encodeString(c(thispath, expected), quote = "\"")
+            }, collapse = "\n"))
+    }
+    if (check_wd) {
+        expected <- path.unsplit(thispath[!i])
+        if (relpath(expected) != ".") {
+            stop("'getwd()' and expected path do not match\n",
+                paste0(c("* getwd() : ", "* expected: "), {
+                    encodeString(c(getwd(), expected), quote = "\"")
                 }, collapse = "\n"))
         }
-        if (check.wd) {
-            expected <- path.unsplit(varname[!i])
-            if (relpath(expected) != ".") {
-                stop("'getwd()' and expected path do not match\n",
-                    paste0(c("* getwd() : ", "* expected: "), {
-                        encodeString(c(getwd(), expected), quote = "\"")
-                    }, collapse = "\n"))
-            }
-        }
-        invisible(TRUE)
-    }, splice = TRUE)
-    eval(call("substitute", expr, list(
-        varname = varname,
-        msg1 = sprintf("'%s' and expected path do not match\n", name),
-        msg2 = as.call(c(as.symbol("c"), as.list(
-                   paste0("* ", format(c(name, "expected")), ": ")
-               ))),
-        name = name
-    )))
+    }
+    invisible(TRUE)
 }
 
 
-check.path <- eval(call("function", as.pairlist(alist(... = )),
-tmp(expression(varname <- .External2(.C_this.path)), "thispath", "this.path()")
-))
-
-
-check.dir <- eval(call("function", as.pairlist(alist(... = )),
-tmp(expression(varname <- .External2(.C_this.path), varname <- .dir(varname)), "thisdir", "this.dir()")
-))
-
-
-rm(tmp)
+check.dir <- function (...)
+{
+    expected <- path.join(...)
+    if (!.IS_SCALAR_STR(expected))
+        stop(gettextf("'%s' must be a character string", "expected", domain = "R"))
+    if (!nzchar(expected))
+        stop(gettextf("'%s' must not be \"\"", "expected"))
+    expected <- path.split.1(expected)
+    if (check_wd <- expected[[1L]] == ".")
+        expected <- expected[-1L]
+    thisdir <- .External2(.C_this_path)
+    thisdir <- .dir(thisdir)
+    thisdir <- path.split.1(thisdir)
+    if (length(thisdir) < length(expected) || {
+        i <- seq_along(thisdir) > length(thisdir) - length(expected)
+        any(thisdir[i] != expected)
+    })
+    {
+        expected <- path.unsplit(expected)
+        thisdir <- path.unsplit(thisdir[i])
+        stop("'this.dir()' and expected path do not match\n",
+            paste0(c("* this.dir(): ", "* expected  : "), {
+                encodeString(c(thisdir, expected), quote = "\"")
+            }, collapse = "\n"))
+    }
+    if (check_wd) {
+        expected <- path.unsplit(thisdir[!i])
+        if (relpath(expected) != ".") {
+            stop("'getwd()' and expected path do not match\n",
+                paste0(c("* getwd() : ", "* expected: "), {
+                  encodeString(c(getwd(), expected), quote = "\"")
+                }, collapse = "\n"))
+        }
+    }
+    invisible(TRUE)
+}
 
 
 check.proj <- function (...)
@@ -95,9 +109,9 @@ check.proj <- function (...)
     if (!nzchar(expected))
         stop(gettextf("'%s' must not be \"\"", "expected"))
     expected <- path.split.1(expected)
-    if (check.wd <- expected[[1L]] == ".")
+    if (check_wd <- expected[[1L]] == ".")
         expected <- expected[-1L]
-    thispath <- .External2(.C_this.path)
+    thispath <- .External2(.C_this_path)
     thisproj <- .proj(.dir(thispath))
     thispath <- path.split.1(thispath)
     thisproj <- path.split.1(thisproj)
@@ -110,7 +124,7 @@ check.proj <- function (...)
                  encodeString(c(thispath, expected), quote = "\"")
              }, collapse = "\n"))
     }
-    if (check.wd) {
+    if (check_wd) {
         expected <- path.unsplit(thispath[!i])
         if (relpath(expected) != ".") {
             stop("'getwd()' and expected path do not match\n",
