@@ -9,7 +9,7 @@ extern int is_abs_path_unix   (const char *s);
 
 #define _drive_width(windows, s, nchar) ((windows) ? (drive_width_windows((s), (nchar))) : (drive_width_unix((s), (nchar))))
 #define _is_abs_path(windows, s)        ((windows) ? (is_abs_path_windows((s)))          : (is_abs_path_unix((s))))
-#ifdef _WIN32
+#if defined(_WIN32)
 #define drive_width(s, nchar) (drive_width_windows((s), (nchar)))
 #define is_abs_path(s) (is_abs_path_windows((s)))
 #else
