@@ -2,7 +2,8 @@
 #define R_THISPATH_NSHOOKS_H
 
 
-#include <Rinternals.h>       /* need definition of SEXP */
+#define R_NO_REMAP
+#include <Rinternals.h>  /* need 'SEXP' */
 
 
 extern SEXP mynamespace,
@@ -34,7 +35,6 @@ extern SEXP expr_commandArgs                              ,
             expr_info_dollar_source_path                  ,
             expr_knitr_output_dir                         ,
             expr_testthat_source_file_uses_brio_read_lines,
-            expr_getOption_topLevelEnvironment            ,
             expr__toplevel_nframe                         ,
             expr__isMethodsDispatchOn                     ,
             expr_UseMethod_lengths                        ;
