@@ -2,7 +2,7 @@
 #include "get_file_from_closure.h"
 
 
-#ifdef _WIN32
+#if defined(_WIN32)
 #define Win32 1  /* this will give us access to UImode in R_ext/RStartup.h */
 #include <R_ext/RStartup.h>  /* definition of UImode */
 #undef Win32
@@ -17,7 +17,7 @@ SEXP do_site_file do_formals
 {
     do_start_no_call_op_rho("site_file", 2);
 #define get_file_from_closure2(sym)                            \
-    (get_file_from_closure(asLogical(CAR(args)), asLogical(CADR(args)), (sym)))
+    (get_file_from_closure(Rf_asLogical(CAR(args)), Rf_asLogical(CADR(args)), (sym)))
     return get_file_from_closure2(_site_fileSymbol);
 }
 
@@ -105,7 +105,7 @@ common_command_line(int *pac, const char **argv,
             }
             else if (!strcmp(*av, "--no-environ"));
             else if (!strcmp(*av, "--verbose"));
-#if R_version_at_least(4, 0, 0)
+#if R_version_at_least(4,0,0)
             else if (!strcmp(*av, "--no-echo") ||
                      !strcmp(*av, "--slave") ||
                      !strcmp(*av, "-s"))
@@ -134,7 +134,7 @@ common_command_line(int *pac, const char **argv,
                     enc[30] = '\0';
                 }
             }
-#ifdef _WIN32
+#if defined(_WIN32)
             else if (!strcmp(*av, "--no-Rconsole"));
 #endif
             else if (!strcmp(*av, "-save") ||
@@ -162,7 +162,7 @@ common_command_line(int *pac, const char **argv,
                     if (ac > 1) { ac--; av++; }
                 }
             }
-#if R_version_at_least(4, 4, 0)
+#if R_version_at_least(4,4,0)
             else if (strncmp(*av, "--max-connections", 17) == 0) {
                 if (strlen(*av) < 19) {
                     if (ac > 1) { ac--; av++; }
@@ -194,12 +194,12 @@ static char *unescape_arg(char *p, const char *avp)
         if (*q == '~' && *(q+1) == '+' && *(q+2) == '~') {
             q += 2;
             *p++ = ' ';
-#if R_version_at_least(3, 6, 0)
+#if R_version_at_least(3,6,0)
         } else if (*q == '~' && *(q+1) == 'n' && *(q+2) == '~') {
             q += 2;
             *p++ = '\n';
 #endif
-#if R_version_at_least(4, 1, 0)
+#if R_version_at_least(4,1,0)
         } else if (*q == '~' && *(q+1) == 't' && *(q+2) == '~') {
             q += 2;
             *p++ = '\t';
@@ -269,43 +269,43 @@ SEXP do_shINFO do_formals
 #define return_shINFO(_ENC_, _NO_SITE_FILE_, _NO_INIT_FILE_, _NO_READLINE_, _NO_ECHO_, _ESS_, _FILE_, _EXPR_, _HAS_INPUT_)\
         do {                                                   \
             int len = 9;                                       \
-            SEXP value = allocVector(VECSXP, len);             \
-            PROTECT(value);                                    \
-            SEXP names = allocVector(STRSXP, len);             \
-            setAttrib(value, R_NamesSymbol, names);            \
+            SEXP value = Rf_allocVector(VECSXP, len);          \
+            Rf_protect(value);                                 \
+            SEXP names = Rf_allocVector(STRSXP, len);          \
+            Rf_setAttrib(value, R_NamesSymbol, names);         \
             int indx = -1;                                     \
-            SET_STRING_ELT(names, ++indx, mkChar("ENC"));      \
+            SET_STRING_ELT(names, ++indx, Rf_mkChar("ENC"));   \
             SET_VECTOR_ELT(value,   indx, (_ENC_));            \
-            SET_STRING_ELT(names, ++indx, mkChar("no_site_file"));\
+            SET_STRING_ELT(names, ++indx, Rf_mkChar("no_site_file"));\
             SET_VECTOR_ELT(value,   indx, (_NO_SITE_FILE_));   \
-            SET_STRING_ELT(names, ++indx, mkChar("no_init_file"));\
+            SET_STRING_ELT(names, ++indx, Rf_mkChar("no_init_file"));\
             SET_VECTOR_ELT(value,   indx, (_NO_INIT_FILE_));   \
-            SET_STRING_ELT(names, ++indx, mkChar("no_readline"));\
+            SET_STRING_ELT(names, ++indx, Rf_mkChar("no_readline"));\
             SET_VECTOR_ELT(value,   indx, (_NO_READLINE_));    \
-            SET_STRING_ELT(names, ++indx, mkChar("no_echo"));  \
+            SET_STRING_ELT(names, ++indx, Rf_mkChar("no_echo"));\
             SET_VECTOR_ELT(value,   indx, (_NO_ECHO_));        \
-            SET_STRING_ELT(names, ++indx, mkChar("ess"));      \
+            SET_STRING_ELT(names, ++indx, Rf_mkChar("ess"));   \
             SET_VECTOR_ELT(value,   indx, (_ESS_));            \
-            SET_STRING_ELT(names, ++indx, mkChar("FILE"));     \
+            SET_STRING_ELT(names, ++indx, Rf_mkChar("FILE"));  \
             SET_VECTOR_ELT(value,   indx, (_FILE_));           \
-            SET_STRING_ELT(names, ++indx, mkChar("EXPR"));     \
+            SET_STRING_ELT(names, ++indx, Rf_mkChar("EXPR"));  \
             SET_VECTOR_ELT(value,   indx, (_EXPR_));           \
-            SET_STRING_ELT(names, ++indx, mkChar("has_input"));\
+            SET_STRING_ELT(names, ++indx, Rf_mkChar("has_input"));\
             SET_VECTOR_ELT(value,   indx, (_HAS_INPUT_));      \
-            UNPROTECT(1);                                      \
+            Rf_unprotect(1);                                   \
             return value;                                      \
         } while (0)
 
 
         return_shINFO(
-            /* ENC          */ ScalarString(NA_STRING),
+            /* ENC          */ Rf_ScalarString(NA_STRING),
             /* no_site_file */ R_LogicalNAValue,
             /* no_init_file */ R_LogicalNAValue,
             /* no_readline  */ R_LogicalNAValue,
             /* no_echo      */ R_LogicalNAValue,
             /* ess          */ R_LogicalNAValue,
-            /* FILE         */ ScalarString(NA_STRING),
-            /* EXPR         */ ScalarString(NA_STRING),
+            /* FILE         */ Rf_ScalarString(NA_STRING),
+            /* EXPR         */ Rf_ScalarString(NA_STRING),
             /* has_input    */ R_LogicalNAValue
         );
     }
@@ -314,8 +314,8 @@ SEXP do_shINFO do_formals
     int ARGC; SEXP ARGV;
 
 
-    ARGV = eval(expr_commandArgs, R_BaseEnv);
-    PROTECT(ARGV);
+    ARGV = Rf_eval(expr_commandArgs, R_BaseEnv);
+    Rf_protect(ARGV);
     ARGC = LENGTH(ARGV);
 
 
@@ -329,7 +329,7 @@ SEXP do_shINFO do_formals
     cmdlines[0] = '\0';
     Rboolean has_input = FALSE;
     Rboolean ess, no_readline;
-#ifdef _WIN32
+#if defined(_WIN32)
     ess = FALSE, no_readline = NA_LOGICAL;
 #else
     ess = NA_LOGICAL, no_readline = FALSE;
@@ -337,20 +337,20 @@ SEXP do_shINFO do_formals
 
 
     if (ARGC <= 1) {
-        UNPROTECT(1);
+        Rf_unprotect(1);
 
 
 #define default_return_shINFO                                  \
         return_shINFO(                                         \
-            ScalarString(has_enc ? mkChar(enc) : NA_STRING),   \
-            ScalarLogical(no_site_file),                       \
-            ScalarLogical(no_init_file),                       \
-            ScalarLogical(no_readline),                        \
-            ScalarLogical(no_echo),                            \
-            ScalarLogical(ess),                                \
-            ScalarString(FILE ? mkChar(FILE) : NA_STRING),     \
-            ScalarString(strlen(cmdlines) ? mkChar(cmdlines) : NA_STRING),\
-            ScalarLogical(has_input)                           \
+            Rf_ScalarString(has_enc ? Rf_mkChar(enc) : NA_STRING),\
+            Rf_ScalarLogical(no_site_file),                    \
+            Rf_ScalarLogical(no_init_file),                    \
+            Rf_ScalarLogical(no_readline),                     \
+            Rf_ScalarLogical(no_echo),                         \
+            Rf_ScalarLogical(ess),                             \
+            Rf_ScalarString(FILE ? Rf_mkChar(FILE) : NA_STRING),\
+            Rf_ScalarString(strlen(cmdlines) ? Rf_mkChar(cmdlines) : NA_STRING),\
+            Rf_ScalarLogical(has_input)                        \
         )
 
 
@@ -361,8 +361,8 @@ SEXP do_shINFO do_formals
     /* determine the number of leading arguments:
      * the arguments up to and including --args
      */
-    SEXP argsChar = mkChar("--args");
-    PROTECT(argsChar);
+    SEXP argsChar = Rf_mkChar("--args");
+    Rf_protect(argsChar);
     int ac = ARGC;
     for (int i = 1; i < ARGC; i++) {
         if (STRING_ELT(ARGV, i) == argsChar) {
@@ -370,14 +370,14 @@ SEXP do_shINFO do_formals
             break;
         }
     }
-    UNPROTECT(1);
+    Rf_unprotect(1);
 
 
     /* copy the arguments from the STRSXP to a *char[] */
     const char *argv[ac];
     for (int i = 0; i < ac; i++)
-        argv[i] = CHAR(STRING_ELT(ARGV, i));
-    UNPROTECT(1);  /* ARGV */
+        argv[i] = R_CHAR(STRING_ELT(ARGV, i));
+    Rf_unprotect(1);  /* ARGV */
     const char **av = argv;
 
 
@@ -410,7 +410,7 @@ SEXP do_shINFO do_formals
             else if (!strcmp(*av, "--internet2"));
             else if (!strcmp(*av, "--mdi"));
             else if (!strcmp(*av, "--sdi") || !strcmp(*av, "--no-mdi")); */
-#if R_version_less_than(4, 2, 0)
+#if R_version_less_than(4,2,0)
             else if (!strncmp(*av, "--max-mem-size", 14)) {
                 if (strlen(*av) < 16) {
                     ac--; av++;
@@ -425,7 +425,7 @@ SEXP do_shINFO do_formals
                 has_input = TRUE;
                 ac--; av++;
                 if (!ac) {
-                    errorcall(R_NilValue, _("option '%s' requires an argument"), "-f");
+                    Rf_errorcall(R_NilValue, _("option '%s' requires an argument"), "-f");
                 }
                 if (strcmp(*av, "-")) { /* av != "-" */
                     FILE = *av;
@@ -441,7 +441,7 @@ SEXP do_shINFO do_formals
                 has_input = TRUE;
                 ac--; av++;
                 if (!ac || !strlen(*av)) {
-                    errorcall(R_NilValue, _("option '%s' requires a non-empty argument"), "-e");
+                    Rf_errorcall(R_NilValue, _("option '%s' requires a non-empty argument"), "-e");
                 }
                 if (strlen(cmdlines) + strlen(*av) + 2 <= 10000) {
                     strcat(cmdlines, *av);
@@ -465,7 +465,7 @@ SEXP do_shINFO do_formals
        If run from the shell script, only Tk|tk|X11|x11 are allowed.
      */
     for (i = 0, avv = av; i < ac; i++, avv++) {
-#if R_version_at_least(3, 5, 0)
+#if R_version_at_least(3,5,0)
         if (!strcmp(*avv, "--args"))
             break;
 #endif
@@ -502,12 +502,12 @@ SEXP do_shINFO do_formals
                 has_input = TRUE;
                 ac--; av++;
                 if (!ac) {
-                    errorcall(R_NilValue, _("option '%s' requires an argument"), "-f");
+                    Rf_errorcall(R_NilValue, _("option '%s' requires an argument"), "-f");
                 }
 #define R_INIT_TREAT_F(_AV_)                                   \
                 if (strcmp(_AV_, "-")) {                       \
                     if (strlen(_AV_) >= PATH_MAX) {            \
-                        errorcall(R_NilValue, _("path given in -f/--file is too long"));\
+                        Rf_errorcall(R_NilValue, _("path given in -f/--file is too long"));\
                     }                                          \
                     char *p = path;                            \
                     p = unescape_arg(p, _AV_);                 \
@@ -525,7 +525,7 @@ SEXP do_shINFO do_formals
                 has_input = TRUE;
                 ac--; av++;
                 if (!ac) {
-                    errorcall(R_NilValue, _("option '%s' requires a non-empty argument"), "-e");
+                    Rf_errorcall(R_NilValue, _("option '%s' requires a non-empty argument"), "-e");
                 }
                 if (strlen(cmdlines) + strlen(*av) + 2 <= 10000) {
                     char *p = cmdlines + strlen(cmdlines);
@@ -537,7 +537,7 @@ SEXP do_shINFO do_formals
             } else if (!strcmp(*av, "--interactive")) {
                 break;
             } else {
-#ifdef HAVE_AQUA
+#if defined(HAVE_AQUA)
                 // r27492: in 2003 launching from 'Finder OSX' passed this
                 if (!strncmp(*av, "-psn", 4)) break;
 #endif
