@@ -1,12 +1,12 @@
 #include "thispathdefn.h"
 
 
-#if R_version_at_least(3, 0, 0)
+#if R_version_at_least(3,0,0)
 R_xlen_t asXLength(SEXP x)
 {
     const R_xlen_t na = -999;
 
-    if (isVectorAtomic(x) && XLENGTH(x) >= 1) {
+    if (Rf_isVectorAtomic(x) && XLENGTH(x) >= 1) {
         switch (TYPEOF(x)) {
         case LGLSXP:
         case INTSXP:
@@ -34,7 +34,7 @@ R_xlen_t asXLength(SEXP x)
     } else if (TYPEOF(x) != CHARSXP)
         return na;
 
-    double d = asReal(x);
+    double d = Rf_asReal(x);
     if (!R_FINITE(d) || d > R_XLEN_T_MAX || d < 0)
         return na;
     else
@@ -43,7 +43,7 @@ R_xlen_t asXLength(SEXP x)
 #else
 R_xlen_t asXLength(SEXP x)
 {
-    return asInteger(x);
+    return Rf_asInteger(x);
 }
 #endif
 
@@ -54,7 +54,7 @@ int ddVal(SEXP symbol)
     char *endp;
     int rval;
 
-    buf = CHAR(PRINTNAME(symbol));
+    buf = R_CHAR(PRINTNAME(symbol));
     if (!strncmp(buf, "..", 2) && strlen(buf) > 2) {
         buf += 2;
         rval = (int) strtol(buf, &endp, 10);
@@ -87,7 +87,7 @@ Rboolean needQuote(SEXP x)
 
 void UNIMPLEMENTED_TYPEt(const char *s, SEXPTYPE t)
 {
-    error(_("unimplemented type '%s' in '%s'\n"), type2char(t), s);
+    Rf_error(_("unimplemented type '%s' in '%s'\n"), Rf_type2char(t), s);
 }
 
 
@@ -102,27 +102,27 @@ const char *EncodeChar(SEXP x)
     /* accepts a CHARSXP and escapes the special / / non-printing characters */
     SEXP expr;
     PROTECT_INDEX indx;
-    PROTECT_WITH_INDEX(expr = CONS(R_FalseValue, R_NilValue), &indx);
+    R_ProtectWithIndex(expr = Rf_cons(R_FalseValue, R_NilValue), &indx);
     SET_TAG(expr, na_encodeSymbol);
-    REPROTECT(expr = LCONS(encodeStringSymbol, CONS(ScalarString(x), expr)), indx);
-    SEXP value = eval(expr, R_BaseEnv);
-    UNPROTECT(1);
-    return CHAR(STRING_ELT(value, 0));
+    R_Reprotect(expr = Rf_lcons(encodeStringSymbol, Rf_cons(Rf_ScalarString(x), expr)), indx);
+    SEXP value = Rf_eval(expr, R_BaseEnv);
+    Rf_unprotect(1);
+    return R_CHAR(STRING_ELT(value, 0));
 }
 
 
 SEXP getInFrame(SEXP sym, SEXP env, int unbound_ok)
 {
-    SEXP value = findVarInFrame(env, sym);
+    SEXP value = Rf_findVarInFrame(env, sym);
     if (!unbound_ok && value == R_UnboundValue)
-        error(_("object '%s' not found"), EncodeChar(PRINTNAME(sym)));
+        Rf_error(_("object '%s' not found"), EncodeChar(PRINTNAME(sym)));
     if (TYPEOF(value) == PROMSXP) {
-        if (PRVALUE(value) == R_UnboundValue) {
-            PROTECT(value);
-            value = eval(value, R_EmptyEnv);
-            UNPROTECT(1);
+        if (ptr_PRVALUE(value) == R_UnboundValue) {
+            Rf_protect(value);
+            value = Rf_eval(value, R_EmptyEnv);
+            Rf_unprotect(1);
         }
-        else value = PRVALUE(value);
+        else value = ptr_PRVALUE(value);
     }
     return value;
 }
@@ -130,17 +130,17 @@ SEXP getInFrame(SEXP sym, SEXP env, int unbound_ok)
 
 SEXP getInList(SEXP sym, SEXP list, int NULL_ok)
 {
-    const char *what = translateChar(PRINTNAME(sym));
-    SEXP names = PROTECT(getAttrib(list, R_NamesSymbol));
-    for (R_xlen_t i = 0, n = xlength(names); i < n; i++) {
-        if (!strcmp(translateChar(STRING_ELT(names, i)), what)) {
-            UNPROTECT(1);
+    const char *what = Rf_translateChar(PRINTNAME(sym));
+    SEXP names = Rf_protect(Rf_getAttrib(list, R_NamesSymbol));
+    for (R_xlen_t i = 0, n = Rf_xlength(names); i < n; i++) {
+        if (!strcmp(Rf_translateChar(STRING_ELT(names, i)), what)) {
+            Rf_unprotect(1);
             return VECTOR_ELT(list, i);
         }
     }
     if (!NULL_ok)
-        error("element '%s' not found", EncodeChar(PRINTNAME(sym)));
-    UNPROTECT(1);
+        Rf_error("element '%s' not found", EncodeChar(PRINTNAME(sym)));
+    Rf_unprotect(1);
     return NULL;
 }
 
@@ -148,14 +148,14 @@ SEXP getInList(SEXP sym, SEXP list, int NULL_ok)
 void INCREMENT_NAMED_defineVar(SEXP symbol, SEXP value, SEXP rho)
 {
     INCREMENT_NAMED(value);
-    defineVar(symbol, value, rho);
+    Rf_defineVar(symbol, value, rho);
 }
 
 
 void MARK_NOT_MUTABLE_defineVar(SEXP symbol, SEXP value, SEXP rho)
 {
     MARK_NOT_MUTABLE(value);
-    defineVar(symbol, value, rho);
+    Rf_defineVar(symbol, value, rho);
 }
 
 
@@ -163,13 +163,15 @@ SEXP findFunction3(SEXP symbol, SEXP rho, SEXP call)
 {
     SEXP vl;
     for (; rho != R_EmptyEnv; rho = ENCLOS(rho)) {
-        vl = findVarInFrame(rho, symbol);
+        vl = Rf_findVarInFrame(rho, symbol);
         if (vl != R_UnboundValue) {
             if (TYPEOF(vl) == PROMSXP) {
-                if (PRVALUE(vl) == R_UnboundValue)
-                    vl = eval(vl, R_EmptyEnv);
-                else
-                    vl = PRVALUE(vl);
+                if (ptr_PRVALUE(vl) == R_UnboundValue) {
+                    Rf_protect(vl);
+                    vl = Rf_eval(vl, R_EmptyEnv);
+                    Rf_unprotect(1);
+                }
+                else vl = ptr_PRVALUE(vl);
             }
             if (TYPEOF(vl) == CLOSXP ||
                 TYPEOF(vl) == BUILTINSXP ||
@@ -178,12 +180,12 @@ SEXP findFunction3(SEXP symbol, SEXP rho, SEXP call)
                 return vl;
             }
             if (vl == R_MissingArg)
-                errorcall(call,
+                Rf_errorcall(call,
                     _("argument \"%s\" is missing, with no default"),
                     EncodeChar(PRINTNAME(symbol)));
         }
     }
-    errorcall(call,
+    Rf_errorcall(call,
         _("could not find function \"%s\""),
         EncodeChar(PRINTNAME(symbol)));
     return R_UnboundValue;
@@ -196,41 +198,40 @@ SEXP findFunction(SEXP symbol, SEXP rho)
 }
 
 
-#if defined(R_CONNECTIONS_VERSION_1)
-SEXP summaryconnection(Rconnection Rcon)
+SEXP summary_connection(SEXP sConn)
 {
-    SEXP value, names;
-    value = allocVector(VECSXP, 7);
-    PROTECT(value);
-    names = allocVector(STRSXP, 7);
-    setAttrib(value, R_NamesSymbol, names);
-    SET_STRING_ELT(names, 0, mkChar("description"));
-    SET_VECTOR_ELT(value, 0, ScalarString(
-        mkCharCE(Rcon->description, (Rcon->enc == CE_UTF8) ? CE_UTF8 : CE_NATIVE)
-    ));
-    SET_STRING_ELT(names, 1, mkChar("class"));
-    SET_VECTOR_ELT(value, 1, mkString(Rcon->class));
-    SET_STRING_ELT(names, 2, mkChar("mode"));
-    SET_VECTOR_ELT(value, 2, mkString(Rcon->mode));
-    SET_STRING_ELT(names, 3, mkChar("text"));
-    SET_VECTOR_ELT(value, 3, mkString(Rcon->text ? "text" : "binary"));
-    SET_STRING_ELT(names, 4, mkChar("opened"));
-    SET_VECTOR_ELT(value, 4, mkString(Rcon->isopen ? "opened" : "closed"));
-    SET_STRING_ELT(names, 5, mkChar("can read"));
-    SET_VECTOR_ELT(value, 5, mkString(Rcon->canread ? "yes" : "no"));
-    SET_STRING_ELT(names, 6, mkChar("can write"));
-    SET_VECTOR_ELT(value, 6, mkString(Rcon->canwrite ? "yes" : "no"));
-    UNPROTECT(1);
+    if (!Rf_inherits(sConn, "connection")) Rf_error(_("invalid connection"));
+    SEXP expr = Rf_lcons(summary_connectionSymbol, Rf_cons(sConn, R_NilValue));
+    Rf_protect(expr);
+    SEXP value = Rf_eval(expr, R_BaseEnv);
+    Rf_unprotect(1);
     return value;
 }
-#else
-SEXP summaryconnection(SEXP sConn)
+#if defined(R_CONNECTIONS_VERSION_1)
+SEXP summary_connection_Rcon_V1(Rconnection Rcon)
 {
-    if (!inherits(sConn, "connection")) error(_("invalid connection"));
-    SEXP expr = LCONS(summary_connectionSymbol, CONS(sConn, R_NilValue));
-    PROTECT(expr);
-    SEXP value = eval(expr, R_BaseEnv);
-    UNPROTECT(1);
+    SEXP value, names;
+    value = Rf_allocVector(VECSXP, 7);
+    Rf_protect(value);
+    names = Rf_allocVector(STRSXP, 7);
+    Rf_setAttrib(value, R_NamesSymbol, names);
+    SET_STRING_ELT(names, 0, Rf_mkChar("description"));
+    SET_VECTOR_ELT(value, 0, Rf_ScalarString(
+        Rf_mkCharCE(Rcon->description, (Rcon->enc == CE_UTF8) ? CE_UTF8 : CE_NATIVE)
+    ));
+    SET_STRING_ELT(names, 1, Rf_mkChar("class"));
+    SET_VECTOR_ELT(value, 1, Rf_mkString(Rcon->class));
+    SET_STRING_ELT(names, 2, Rf_mkChar("mode"));
+    SET_VECTOR_ELT(value, 2, Rf_mkString(Rcon->mode));
+    SET_STRING_ELT(names, 3, Rf_mkChar("text"));
+    SET_VECTOR_ELT(value, 3, Rf_mkString(Rcon->text ? "text" : "binary"));
+    SET_STRING_ELT(names, 4, Rf_mkChar("opened"));
+    SET_VECTOR_ELT(value, 4, Rf_mkString(Rcon->isopen ? "opened" : "closed"));
+    SET_STRING_ELT(names, 5, Rf_mkChar("can read"));
+    SET_VECTOR_ELT(value, 5, Rf_mkString(Rcon->canread ? "yes" : "no"));
+    SET_STRING_ELT(names, 6, Rf_mkChar("can write"));
+    SET_VECTOR_ELT(value, 6, Rf_mkString(Rcon->canwrite ? "yes" : "no"));
+    Rf_unprotect(1);
     return value;
 }
 #endif
@@ -239,9 +240,9 @@ SEXP summaryconnection(SEXP sConn)
 SEXP DocumentContext(void)
 {
     SEXP documentcontext = R_NewEnv(mynamespace, TRUE, 10);
-    PROTECT(documentcontext);
-    setAttrib(documentcontext, R_ClassSymbol, DocumentContextClass);
-    UNPROTECT(1);
+    Rf_protect(documentcontext);
+    Rf_setAttrib(documentcontext, R_ClassSymbol, DocumentContextClass);
+    Rf_unprotect(1);
     return documentcontext;
 }
 
@@ -257,14 +258,22 @@ SEXP DocumentContext(void)
 #define _assign(ofile, documentcontext)                        \
     INCREMENT_NAMED_defineVar(ofileSymbol, (ofile), (documentcontext));\
     SEXP e = makePROMISE(R_NilValue, (documentcontext));       \
-    defineVar(fileSymbol, e, (documentcontext))
+    Rf_protect(e);                                             \
+    Rf_defineVar(fileSymbol, e, (documentcontext))
 
 
 #define _assign_default(srcfile_original, owd, trans, documentcontext, na)\
     if (srcfile_original) {                                    \
-        SET_PRCODE(e, LCONS(_normalizePath_srcfilealiasSymbol, \
-                            CONS(srcfile_original,             \
-                                 CONS(trans, R_NilValue))));   \
+        ptr_SET_PRCODE(                                        \
+            e,                                                 \
+            Rf_lcons(                                          \
+                _normalizePath_srcfilealiasSymbol,             \
+                Rf_cons(                                       \
+                    srcfile_original,                          \
+                    Rf_cons(trans, R_NilValue)                 \
+                )                                              \
+            )                                                  \
+        );                                                     \
     }                                                          \
     else if (owd) {                                            \
         INCREMENT_NAMED_defineVar(wdSymbol, owd, documentcontext);\
@@ -274,10 +283,10 @@ SEXP DocumentContext(void)
         case NA_NOT_DIR: sym = _normalizePath_not_dir_againstSymbol; break;\
         case NA_FIX_DIR: sym = _normalizePath_fix_dir_againstSymbol; break;\
         default:                                               \
-            errorcall(R_NilValue, _("invalid '%s' value"), "na");\
+            Rf_errorcall(R_NilValue, _("invalid '%s' value"), "na");\
             sym = R_NilValue;                                  \
         }                                                      \
-        SET_PRCODE(e, LCONS(sym, CONS(wdSymbol, CONS(trans, R_NilValue))));\
+        ptr_SET_PRCODE(e, Rf_lcons(sym, Rf_cons(wdSymbol, Rf_cons(trans, R_NilValue))));\
     }                                                          \
     else {                                                     \
         SEXP sym;                                              \
@@ -286,10 +295,10 @@ SEXP DocumentContext(void)
         case NA_NOT_DIR: sym = _normalizePath_not_dirSymbol; break;\
         case NA_FIX_DIR: sym = _normalizePath_fix_dirSymbol; break;\
         default:                                               \
-            errorcall(R_NilValue, _("invalid '%s' value"), "na");\
+            Rf_errorcall(R_NilValue, _("invalid '%s' value"), "na");\
             sym = R_NilValue;                                  \
         }                                                      \
-        SET_PRCODE(e, LCONS(sym, CONS(trans, R_NilValue)));    \
+        ptr_SET_PRCODE(e, Rf_lcons(sym, Rf_cons(trans, R_NilValue)));\
     }
 
 
@@ -301,21 +310,21 @@ void assign_default(SEXP srcfile_original, SEXP owd, SEXP ofile, SEXP file, SEXP
     const char *url;
     cetype_t ienc = CE_NATIVE;
 // https://github.com/wch/r-source/blob/trunk/src/main/connections.c#L5531
-#ifdef _WIN32
+#if defined(_WIN32)
     if (!IS_ASCII(file)) {
         ienc = CE_UTF8;
-        url = translateCharUTF8(file);
+        url = Rf_translateCharUTF8(file);
     } else {
-        ienc = getCharCE(file);
-        url = CHAR(file);
+        ienc = Rf_getCharCE(file);
+        url = R_CHAR(file);
     }
 #else
-    url = translateChar(file);
+    url = Rf_translateChar(file);
 #endif
 
 
-    _assign_default(srcfile_original, owd, ScalarString(mkCharCE(url, ienc)), documentcontext, na);
-    return;
+    _assign_default(srcfile_original, owd, Rf_ScalarString(Rf_mkCharCE(url, ienc)), documentcontext, na);
+    Rf_unprotect(1);
 }
 
 
@@ -329,36 +338,37 @@ void assign_file_uri(SEXP srcfile_original, SEXP owd, SEXP ofile, SEXP file, SEX
     const char *url;
     cetype_t ienc = CE_NATIVE;
 // https://github.com/wch/r-source/blob/trunk/src/main/connections.c#L5531
-#ifdef _WIN32
+#if defined(_WIN32)
     if (!IS_ASCII(file)) {
         ienc = CE_UTF8;
-        url = translateCharUTF8(file);
+        url = Rf_translateCharUTF8(file);
     } else {
-        ienc = getCharCE(file);
-        url = CHAR(file);
+        ienc = Rf_getCharCE(file);
+        url = R_CHAR(file);
     }
 #else
-    url = translateChar(file);
+    url = Rf_translateChar(file);
 #endif
 
 
 // https://github.com/wch/r-source/blob/trunk/src/main/connections.c#L5650
     int nh = 7;
-#ifdef _WIN32
+#if defined(_WIN32)
     if (strlen(url) > 9 && url[7] == '/' && url[9] == ':') nh = 8;
 #endif
 
 
-    _assign_default(srcfile_original, owd, ScalarString(mkCharCE(url + nh, ienc)), documentcontext, na);
+    _assign_default(srcfile_original, owd, Rf_ScalarString(Rf_mkCharCE(url + nh, ienc)), documentcontext, na);
+    Rf_unprotect(1);
 }
 
 
 void assign_file_uri2(SEXP srcfile_original, SEXP owd, SEXP description, SEXP documentcontext, NORMALIZE_ACTION na)
 {
-    const char *url = CHAR(description);
+    const char *url = R_CHAR(description);
     char _buf[8 + strlen(url) + 1];
     char *buf = _buf;
-#ifdef _WIN32
+#if defined(_WIN32)
     if (strlen(url) > 1 && url[1] == ':') {
         strcpy(buf, "file:///");
         strcpy(buf + 8, url);
@@ -373,9 +383,10 @@ void assign_file_uri2(SEXP srcfile_original, SEXP owd, SEXP description, SEXP do
 
 
 
-    SEXP ofile = ScalarString(mkCharCE(_buf, getCharCE(description)));
+    SEXP ofile = Rf_ScalarString(Rf_mkCharCE(_buf, Rf_getCharCE(description)));
     _assign(ofile, documentcontext);
-    _assign_default(srcfile_original, owd, ScalarString(description), documentcontext, na);
+    _assign_default(srcfile_original, owd, Rf_ScalarString(description), documentcontext, na);
+    Rf_unprotect(1);
 }
 
 
@@ -387,21 +398,26 @@ void assign_url(SEXP ofile, SEXP file, SEXP documentcontext)
     const char *url;
     cetype_t ienc = CE_NATIVE;
 // https://github.com/wch/r-source/blob/trunk/src/main/connections.c#L5531
-#ifdef _WIN32
+#if defined(_WIN32)
     if (!IS_ASCII(file)) {
         ienc = CE_UTF8;
-        url = translateCharUTF8(file);
+        url = Rf_translateCharUTF8(file);
     } else {
-        ienc = getCharCE(file);
-        url = CHAR(file);
+        ienc = Rf_getCharCE(file);
+        url = R_CHAR(file);
     }
 #else
-    url = translateChar(file);
+    url = Rf_translateChar(file);
 #endif
 
 
-    SET_PRCODE(e, LCONS(_normalizeURL_1Symbol, CONS(ScalarString(mkCharCE(url, ienc)), R_NilValue)));
-    eval(e, R_EmptyEnv);  /* force the promise */
+    ptr_SET_PRCODE(
+        e,
+        Rf_lcons(_normalizeURL_1Symbol,
+            Rf_cons(Rf_ScalarString(Rf_mkCharCE(url, ienc)), R_NilValue))
+    );
+    Rf_eval(e, R_EmptyEnv);  /* force the promise */
+    Rf_unprotect(1);
 }
 
 
@@ -429,10 +445,10 @@ SEXP get_debugSource(void)
 
     SEXP name;
     for (SEXP t = ENCLOS(R_GlobalEnv); t != R_EmptyEnv ; t = ENCLOS(t)) {
-        name = getAttrib(t, R_NameSymbol);
-        if (isString(name) &&
-            length(name) > 0 &&
-            !strcmp(translateChar(STRING_ELT(name, 0)), what))
+        name = Rf_getAttrib(t, R_NameSymbol);
+        if (Rf_isString(name) &&
+            Rf_length(name) > 0 &&
+            !strcmp(Rf_translateChar(STRING_ELT(name, 0)), what))
         {
             return getInFrame(debugSourceSymbol, t, TRUE);
         }
@@ -443,39 +459,52 @@ SEXP get_debugSource(void)
 }
 
 
+int my_HASHASH(SEXP x)
+{
+#if defined(R_THIS_PATH_DEVEL) || R_version_less_than(4,5,0)
+    return HASHTAB(x) != R_NilValue;
+#else
+    static SEXP env_profileSymbol = NULL;
+    if (env_profileSymbol == NULL)
+        env_profileSymbol = Rf_install("env.profile");
+    SEXP expr = Rf_lcons(env_profileSymbol, Rf_cons(x, R_NilValue));
+    Rf_protect(expr);
+    int value = Rf_eval(expr, R_BaseEnv) != R_NilValue;
+    Rf_unprotect(1);
+    return value;
+#endif
+}
+
+
 SEXP duplicateEnv(SEXP env)
 {
     if (TYPEOF(env) != ENVSXP)
-        error("wtf are you doing? %s %d", __FILE__, __LINE__);
+        Rf_error("wtf are you doing? %s %d", __FILE__, __LINE__);
     if (env == R_EmptyEnv)
         return env;
     SEXP value = R_NewEnv(
         /* enclos */ ENCLOS(env),
-        /* hash */ HASHTAB(env) != R_NilValue,
+        /* hash */ my_HASHASH(env),
         /* size */ 29
     );
-    PROTECT(value);
+    Rf_protect(value);
     SEXP names = R_lsInternal3(env, TRUE, FALSE);
-    PROTECT(names);
+    Rf_protect(names);
     for (int i = LENGTH(names) - 1; i >= 0; i--) {
-        SEXP sym = installTrChar(STRING_ELT(names, i));
-#if R_version_at_least(4, 0, 0)
+        SEXP sym = Rf_installTrChar(STRING_ELT(names, i));
+#if R_version_at_least(4,0,0)
         if (R_BindingIsActive(sym, env))
             R_MakeActiveBinding(sym, R_ActiveBindingFunction(sym, env), value);
         else
 #endif
-            INCREMENT_NAMED_defineVar(sym, findVarInFrame(env, sym), value);
+            INCREMENT_NAMED_defineVar(sym, Rf_findVarInFrame(env, sym), value);
         if (R_BindingIsLocked(sym, env))
             R_LockBinding(sym, value);
     }
     if (R_EnvironmentIsLocked(env))
         R_LockEnvironment(value, FALSE);
     DUPLICATE_ATTRIB(/* to */ value, /* from */ env);
-    if (OBJECT(env))
-        SET_OBJECT(value, 1);
-    if (IS_S4_OBJECT(env))
-        SET_S4_OBJECT(value);
-    UNPROTECT(2);
+    Rf_unprotect(2);
     return value;
 }
 
