@@ -2,6 +2,7 @@
 #define R_THISPATH_THISPATHDEFN_H
 
 
+#define R_NO_REMAP
 #include <R.h>
 #include <Rinternals.h>
 #include "devel.h"
@@ -21,16 +22,16 @@
 /* R */
 
 
-extern Rboolean pmatch(SEXP, SEXP, Rboolean);
+extern Rboolean Rf_pmatch(SEXP, SEXP, Rboolean);
 
 
-extern void SET_PRCODE (SEXP x, SEXP v);
-extern void SET_PRENV  (SEXP x, SEXP v);
-extern void SET_PRSEEN (SEXP x, int  v);
-extern void SET_PRVALUE(SEXP x, SEXP v);
+#if defined(R_THIS_PATH_DEVEL) || R_version_less_than(4,5,0)
+#define R_THIS_PATH_HAS_PRSEEN
+extern void SET_PRSEEN(SEXP x, int v);
+#endif
 
 
-extern SEXP topenv(SEXP target, SEXP envir);
+extern SEXP Rf_topenv(SEXP target, SEXP envir);
 
 
 extern void R_LockBinding(SEXP sym, SEXP env);
@@ -74,10 +75,9 @@ extern SEXP findFunction3(SEXP symbol, SEXP rho, SEXP call);
 extern SEXP findFunction(SEXP symbol, SEXP rho);
 
 
+extern SEXP summary_connection(SEXP sConn);
 #if defined(R_CONNECTIONS_VERSION_1)
-extern SEXP summaryconnection(Rconnection Rcon);
-#else
-extern SEXP summaryconnection(SEXP sConn);
+extern SEXP summary_connection_Rcon_V1(Rconnection Rcon);
 #endif
 
 
@@ -99,9 +99,9 @@ extern int _maybe_unembedded_shell;
 extern Rboolean _in_site_file;
 extern Rboolean _in_init_file;
 extern SEXP get_debugSource(void);
-#define gui_rstudio            ((_gui_rstudio            != -1) ? (_gui_rstudio           ) : (_gui_rstudio            = asLogical(getFromMyNS(_GUI_RStudioSymbol           ))))
-#define maybe_unembedded_shell ((_maybe_unembedded_shell != -1) ? (_maybe_unembedded_shell) : (_maybe_unembedded_shell = asLogical(getFromMyNS(_maybe_unembedded_shellSymbol))))
-#define in_site_file           ((!_in_site_file               ) ? (_in_site_file          ) : (_in_site_file           = asLogical(getFromMyNS(_in_site_fileSymbol          ))))
+#define gui_rstudio            ((_gui_rstudio            != -1) ? (_gui_rstudio           ) : (_gui_rstudio            = Rf_asLogical(getFromMyNS(_GUI_RStudioSymbol           ))))
+#define maybe_unembedded_shell ((_maybe_unembedded_shell != -1) ? (_maybe_unembedded_shell) : (_maybe_unembedded_shell = Rf_asLogical(getFromMyNS(_maybe_unembedded_shellSymbol))))
+#define in_site_file           ((!_in_site_file               ) ? (_in_site_file          ) : (_in_site_file           = Rf_asLogical(getFromMyNS(_in_site_fileSymbol          ))))
 #define in_init_file           (_in_init_file)
 
 
@@ -109,7 +109,7 @@ extern SEXP get_debugSource(void);
 
 
 // extern int IS_BYTES(SEXP x);
-#define IS_BYTES(x) (getCharCE((x)) == CE_BYTES)
+#define IS_BYTES(x) (Rf_getCharCE((x)) == CE_BYTES)
 // extern int IS_LATIN1(SEXP x);
 
 
@@ -147,40 +147,47 @@ extern SEXP get_debugSource(void);
 #define identical(x, y) ( R_compute_identical((x), (y), 127) )
 
 
-#if defined(R_CONNECTIONS_VERSION_1)
-typedef struct gzconn {
-    Rconnection con;
-    /* there are other components to an Rgzconn, but only 'con' is needed */
-} *Rgzconn;
-#define get_description_and_class                              \
-            /* as I said before, R_GetConnection() is not a part of the R API.\
-               DO NOT USE IT unless you are certain of what you are doing and\
-               accept the potential consequences and drawbacks */\
-            Rconnection Rcon = R_GetConnection(ofile);         \
-            if (Rcon->isGzcon) {                               \
-                Rcon = (((Rgzconn)(Rcon->private))->con);      \
-                if (Rcon->isGzcon) error("%s; should never happen, please report!", _("invalid connection"));\
-            }                                                  \
-            SEXP description = mkCharCE(Rcon->description, (Rcon->enc == CE_UTF8) ? CE_UTF8 : CE_NATIVE);\
-            PROTECT(description); nprotect++;                  \
-            const char *klass = Rcon->class
-#define Rcon_or_summary Rcon
-#else
-#define get_description_and_class                              \
-            SEXP summary = summaryconnection(ofile);           \
-            PROTECT(summary); nprotect++;                      \
-            SEXP description = STRING_ELT(VECTOR_ELT(summary, 0), 0);\
-            const char *klass = CHAR(STRING_ELT(VECTOR_ELT(summary, 1), 0));\
+#define get_description_and_class_declarations                 \
+            SEXP summary = NULL;                               \
+            SEXP description;                                  \
+            const char *klass
+#define get_description_and_class_SEXP                         \
+            summary = summary_connection(ofile);               \
+            Rf_protect(summary); nprotect++;                   \
+            description = STRING_ELT(VECTOR_ELT(summary, 0), 0);\
+            klass = R_CHAR(STRING_ELT(VECTOR_ELT(summary, 1), 0));\
             if (streql(klass, "gzcon")) {                      \
                 const char *msg = "'this.path' cannot be used within a 'gzcon()'";\
                 SEXP call = getCurrentCall(rho);               \
-                PROTECT(call);                                 \
+                Rf_protect(call);                              \
                 SEXP cond = ThisPathNotFoundError(msg, call);  \
-                PROTECT(cond);                                 \
+                Rf_protect(cond);                              \
                 stop(cond);                                    \
-                UNPROTECT(2);                                  \
+                Rf_unprotect(2);                               \
             }
-#define Rcon_or_summary summary
+#define UnrecognizedConnectionClassError_SEXP ThisPathUnrecognizedConnectionClassError(R_NilValue, summary)
+#if defined(R_CONNECTIONS_VERSION_1)
+#define get_description_and_class                              \
+            Rconnection Rcon = NULL;                           \
+            get_description_and_class_declarations;            \
+            if (ptr_R_GetConnection) {                         \
+                Rcon = ptr_R_GetConnection(ofile);             \
+                if (Rcon->isGzcon) {                           \
+                    Rcon = (((Rgzconn)(Rcon->private))->con);  \
+                    if (Rcon->isGzcon) Rf_error("%s; should never happen, please report!", _("invalid connection"));\
+                }                                              \
+                description = Rf_mkCharCE(Rcon->description, (Rcon->enc == CE_UTF8) ? CE_UTF8 : CE_NATIVE);\
+                Rf_protect(description); nprotect++;           \
+                klass = Rcon->class;                           \
+            } else {                                           \
+                get_description_and_class_SEXP;                \
+            }
+#define UnrecognizedConnectionClassError (Rcon ? ThisPathUnrecognizedConnectionClassError_Rcon_V1(R_NilValue, Rcon) : UnrecognizedConnectionClassError_SEXP)
+#else
+#define get_description_and_class                              \
+            get_description_and_class_declarations;            \
+            get_description_and_class_SEXP
+#define UnrecognizedConnectionClassError UnrecognizedConnectionClassError_SEXP
 #endif
 
 
@@ -210,72 +217,72 @@ typedef struct gzconn {
     ignore_url, ignore_file_uri, source, srcfile_original)     \
 do {                                                           \
     int nprotect = 0;                                          \
-    PROTECT(documentcontext = DocumentContext()); nprotect++;  \
+    Rf_protect(documentcontext = DocumentContext()); nprotect++;\
     if (TYPEOF(ofile) == STRSXP) {                             \
         if (XLENGTH(ofile) != 1)                               \
-            errorcall(call, "'%s' must be a character string", EncodeChar(PRINTNAME(sym)));\
+            Rf_errorcall(call, "'%s' must be a character string", EncodeChar(PRINTNAME(sym)));\
         SEXP file = STRING_ELT(ofile, 0);                      \
         if (file == NA_STRING)                                 \
-            errorcall(call, "invalid '%s', must not be NA", EncodeChar(PRINTNAME(sym)));\
+            Rf_errorcall(call, "invalid '%s', must not be NA", EncodeChar(PRINTNAME(sym)));\
         if (ofilearg != NULL) {                                \
             if (!IS_SCALAR(ofilearg, STRSXP))                  \
-                errorcall(call, "'%s' must be a character string", "ofile");\
+                Rf_errorcall(call, "'%s' must be a character string", "ofile");\
             if (STRING_ELT(ofilearg, 0) == NA_STRING)          \
-                errorcall(call, "invalid '%s', must not be NA", "ofile");\
+                Rf_errorcall(call, "invalid '%s', must not be NA", "ofile");\
         }                                                      \
         const char *url;                                       \
         if (conv2utf8) {                                       \
             /* https://github.com/wch/r-source/blob/trunk/src/main/util.c#L2257 */\
             if (IS_UTF8(file) || IS_ASCII(file) || IS_BYTES(file))\
-                url = CHAR(file);                              \
+                url = R_CHAR(file);                            \
             else {                                             \
-                url = translateCharUTF8(file);                 \
-                file = mkCharCE(url, CE_UTF8);                 \
-                PROTECT(file); nprotect++;                     \
+                url = Rf_translateCharUTF8(file);              \
+                file = Rf_mkCharCE(url, CE_UTF8);              \
+                Rf_protect(file); nprotect++;                  \
             }                                                  \
         }                                                      \
-        else url = CHAR(file);                                 \
+        else url = R_CHAR(file);                               \
         if (!ignore_blank_string && !(LENGTH(file) > 0)) {     \
             if (allow_blank_string) {                          \
                 documentcontext = R_EmptyEnv;                  \
                 if (assign_returnvalue) {                      \
-                    returnvalue = PROTECT(ofile); nprotect++;  \
+                    returnvalue = Rf_protect(ofile); nprotect++;\
                 }                                              \
             }                                                  \
             else                                               \
-                errorcall(call, "invalid '%s', must not be \"\"", EncodeChar(PRINTNAME(sym)));\
+                Rf_errorcall(call, "invalid '%s', must not be \"\"", EncodeChar(PRINTNAME(sym)));\
         }                                                      \
         else if (!ignore_clipboard && is_clipboard(url)) {     \
             if (allow_clipboard) {                             \
                 documentcontext = R_EmptyEnv;                  \
                 if (assign_returnvalue) {                      \
-                    returnvalue = PROTECT(ofile); nprotect++;  \
+                    returnvalue = Rf_protect(ofile); nprotect++;\
                 }                                              \
             }                                                  \
             else                                               \
-                errorcall(call, "invalid '%s', %s", EncodeChar(PRINTNAME(sym)), must_not_be_clipboard_message);\
+                Rf_errorcall(call, "invalid '%s', %s", EncodeChar(PRINTNAME(sym)), must_not_be_clipboard_message);\
         }                                                      \
         else if (!ignore_stdin && streql(url, "stdin")) {      \
             if (allow_stdin) {                                 \
                 documentcontext = R_EmptyEnv;                  \
                 if (assign_returnvalue) {                      \
-                    returnvalue = PROTECT(ofile); nprotect++;  \
+                    returnvalue = Rf_protect(ofile); nprotect++;\
                 }                                              \
             }                                                  \
             else                                               \
-                errorcall(call, "invalid '%s', must not be \"stdin\"", EncodeChar(PRINTNAME(sym)));\
+                Rf_errorcall(call, "invalid '%s', must not be \"stdin\"", EncodeChar(PRINTNAME(sym)));\
         }                                                      \
         else if (!ignore_url && is_url(url)) {                 \
             if (allow_url) {                                   \
                 assign_url(ofile, file, documentcontext);      \
                 if (assign_returnvalue) {                      \
-                    returnvalue = PROTECT(ofile); nprotect++;  \
+                    returnvalue = Rf_protect(ofile); nprotect++;\
                 }                                              \
                 if (ofilearg != NULL)                          \
                     overwrite_ofile(ofilearg, documentcontext);\
             }                                                  \
             else                                               \
-                errorcall(call, "invalid '%s', cannot be a URL", EncodeChar(PRINTNAME(sym)));\
+                Rf_errorcall(call, "invalid '%s', cannot be a URL", EncodeChar(PRINTNAME(sym)));\
         }                                                      \
         else if (!ignore_file_uri && is_file_uri(url)) {       \
             if (allow_file_uri) {                              \
@@ -286,15 +293,15 @@ do {                                                           \
                 else if (maybe_chdir) {                        \
                     SEXP owd = getowd;                         \
                     if (hasowd) {                              \
-                        PROTECT(owd);                          \
+                        Rf_protect(owd);                       \
                         assign_file_uri(NULL, owd, ofile, file, documentcontext, normalize_action);\
-                        UNPROTECT(1);                          \
+                        Rf_unprotect(1);                       \
                     }                                          \
                     else assign_file_uri(NULL, NULL, ofile, file, documentcontext, normalize_action);\
                 }                                              \
                 else assign_file_uri(NULL, NULL, ofile, file, documentcontext, normalize_action);\
                 if (assign_returnvalue) {                      \
-                    returnvalue = PROTECT(shallow_duplicate(ofile)); nprotect++;\
+                    returnvalue = Rf_protect(Rf_shallow_duplicate(ofile)); nprotect++;\
                     SET_STRING_ELT(returnvalue, 0, STRING_ELT(getInFrame(fileSymbol, documentcontext, FALSE), 0));\
                 }                                              \
                 else if (forcepromise)                         \
@@ -303,7 +310,7 @@ do {                                                           \
                     overwrite_ofile(ofilearg, documentcontext);\
             }                                                  \
             else                                               \
-                errorcall(call, "invalid '%s', cannot be a file URI", EncodeChar(PRINTNAME(sym)));\
+                Rf_errorcall(call, "invalid '%s', cannot be a file URI", EncodeChar(PRINTNAME(sym)));\
         }                                                      \
         else {                                                 \
             SEXP _srcfile_original = srcfile_original;         \
@@ -313,15 +320,15 @@ do {                                                           \
             else if (maybe_chdir) {                            \
                 SEXP owd = getowd;                             \
                 if (hasowd) {                                  \
-                    PROTECT(owd);                              \
+                    Rf_protect(owd);                           \
                     assign_default(NULL, owd, ofile, file, documentcontext, normalize_action);\
-                    UNPROTECT(1);                              \
+                    Rf_unprotect(1);                           \
                 }                                              \
                 else assign_default(NULL, NULL, ofile, file, documentcontext, normalize_action);\
             }                                                  \
             else assign_default(NULL, NULL, ofile, file, documentcontext, normalize_action);\
             if (assign_returnvalue) {                          \
-                returnvalue = PROTECT(shallow_duplicate(ofile)); nprotect++;\
+                returnvalue = Rf_protect(Rf_shallow_duplicate(ofile)); nprotect++;\
                 SET_STRING_ELT(returnvalue, 0, STRING_ELT(getInFrame(fileSymbol, documentcontext, FALSE), 0));\
             }                                                  \
             else if (forcepromise)                             \
@@ -332,35 +339,38 @@ do {                                                           \
     }                                                          \
     else {                                                     \
         if (character_only)                                    \
-            errorcall(call, "'%s' must be a character string", EncodeChar(PRINTNAME(sym)));\
-        else if (!(IS_SCALAR(ofile, INTSXP) && inherits(ofile, "connection")))\
-            errorcall(call, "invalid '%s', must be a character string or connection", EncodeChar(PRINTNAME(sym)));\
+            Rf_errorcall(call, "'%s' must be a character string", EncodeChar(PRINTNAME(sym)));\
+        else if (!(IS_SCALAR(ofile, INTSXP) && Rf_inherits(ofile, "connection")))\
+            Rf_errorcall(call, "invalid '%s', must be a character string or connection", EncodeChar(PRINTNAME(sym)));\
         else {                                                 \
             if (ofilearg != NULL) {                            \
                 if (!identical(ofile, ofilearg)) {             \
-                    errorcall(call, "invalid '%s', must be identical to '%s'",\
+                    Rf_errorcall(call, "invalid '%s', must be identical to '%s'",\
                         "ofile", EncodeChar(PRINTNAME(sym)));  \
                 }                                              \
             }                                                  \
             get_description_and_class;                         \
-            if (streql(klass, "file"  ) ||                     \
-                streql(klass, "gzfile") ||                     \
-                streql(klass, "bzfile") ||                     \
-                streql(klass, "xzfile") ||                     \
-                streql(klass, "fifo"  ))                       \
-            {                                                  \
+            if (streql(klass, "file")) {                       \
                 assign_file_uri2(NULL, NULL, description, documentcontext, normalize_action);\
                 if (forcepromise) getInFrame(fileSymbol, documentcontext, FALSE);\
             }                                                  \
+            else if (streql(klass, "gzfile") ||                \
+                     streql(klass, "bzfile") ||                \
+                     streql(klass, "xzfile") ||                \
+                     streql(klass, "fifo"  ))                  \
+            {                                                  \
+                assign_default(NULL, NULL, Rf_ScalarString(description), description, documentcontext, normalize_action);\
+                if (forcepromise) getInFrame(fileSymbol, documentcontext, FALSE);\
+            }                                                  \
             else if (streql(klass, "url-libcurl") ||           \
                      streql(klass, "url-wininet"))             \
             {                                                  \
                 if (allow_url) {                               \
-                    assign_url(ScalarString(description), description, documentcontext);\
+                    assign_url(Rf_ScalarString(description), description, documentcontext);\
                     if (forcepromise) getInFrame(fileSymbol, documentcontext, FALSE);\
                 }                                              \
                 else                                           \
-                    errorcall(call, "invalid '%s', cannot be a URL connection", EncodeChar(PRINTNAME(sym)));\
+                    Rf_errorcall(call, "invalid '%s', cannot be a URL connection", EncodeChar(PRINTNAME(sym)));\
             }                                                  \
             else if (streql(klass, "unz")) {                   \
                 /* we save this error to throw later because   \
@@ -380,53 +390,53 @@ do {                                                           \
                  */                                            \
                 if (allow_unz) {                               \
                     INCREMENT_NAMED_defineVar(errcndSymbol              , ThisPathInZipFileError(R_NilValue, description), documentcontext);\
-                    INCREMENT_NAMED_defineVar(for_msgSymbol             , ScalarString(description)                      , documentcontext);\
-                                    defineVar(associated_with_fileSymbol, R_TrueValue                                    , documentcontext);\
+                    INCREMENT_NAMED_defineVar(for_msgSymbol             , Rf_ScalarString(description)                   , documentcontext);\
+                                 Rf_defineVar(associated_with_fileSymbol, R_TrueValue                                    , documentcontext);\
                 }                                              \
                 else                                           \
-                    errorcall(call, "invalid '%s', cannot be a %s connection", EncodeChar(PRINTNAME(sym)), klass);\
+                    Rf_errorcall(call, "invalid '%s', cannot be a %s connection", EncodeChar(PRINTNAME(sym)), klass);\
             }                                                  \
             else if (is_clipboard(klass)) {                    \
                 if (allow_clipboard)                           \
                     documentcontext = R_EmptyEnv;              \
                 else                                           \
-                    errorcall(call, "invalid '%s', cannot be a clipboard connection", EncodeChar(PRINTNAME(sym)));\
+                    Rf_errorcall(call, "invalid '%s', cannot be a clipboard connection", EncodeChar(PRINTNAME(sym)));\
             }                                                  \
             else if (streql(klass, "pipe")) {                  \
                 if (allow_pipe)                                \
                     documentcontext = R_EmptyEnv;              \
                 else                                           \
-                    errorcall(call, "invalid '%s', cannot be a %s connection", EncodeChar(PRINTNAME(sym)), klass);\
+                    Rf_errorcall(call, "invalid '%s', cannot be a %s connection", EncodeChar(PRINTNAME(sym)), klass);\
             }                                                  \
             else if (streql(klass, "terminal")) {              \
                 if (allow_terminal)                            \
                     documentcontext = R_EmptyEnv;              \
                 else                                           \
-                    errorcall(call, "invalid '%s', cannot be a %s connection", EncodeChar(PRINTNAME(sym)), klass);\
+                    Rf_errorcall(call, "invalid '%s', cannot be a %s connection", EncodeChar(PRINTNAME(sym)), klass);\
             }                                                  \
             else if (streql(klass, "textConnection")) {        \
                 if (allow_textConnection)                      \
                     documentcontext = R_EmptyEnv;              \
                 else                                           \
-                    errorcall(call, "invalid '%s', cannot be a %s", EncodeChar(PRINTNAME(sym)), klass);\
+                    Rf_errorcall(call, "invalid '%s', cannot be a %s", EncodeChar(PRINTNAME(sym)), klass);\
             }                                                  \
             else if (streql(klass, "rawConnection")) {         \
                 if (allow_rawConnection)                       \
                     documentcontext = R_EmptyEnv;              \
                 else                                           \
-                    errorcall(call, "invalid '%s', cannot be a %s", EncodeChar(PRINTNAME(sym)), klass);\
+                    Rf_errorcall(call, "invalid '%s', cannot be a %s", EncodeChar(PRINTNAME(sym)), klass);\
             }                                                  \
             else if (streql(klass, "sockconn")) {              \
                 if (allow_sockconn)                            \
                     documentcontext = R_EmptyEnv;              \
                 else                                           \
-                    errorcall(call, "invalid '%s', cannot be a %s", EncodeChar(PRINTNAME(sym)), klass);\
+                    Rf_errorcall(call, "invalid '%s', cannot be a %s", EncodeChar(PRINTNAME(sym)), klass);\
             }                                                  \
             else if (streql(klass, "servsockconn")) {          \
                 if (allow_servsockconn)                        \
                     documentcontext = R_EmptyEnv;              \
                 else                                           \
-                    errorcall(call, "invalid '%s', cannot be a %s", EncodeChar(PRINTNAME(sym)), klass);\
+                    Rf_errorcall(call, "invalid '%s', cannot be a %s", EncodeChar(PRINTNAME(sym)), klass);\
             }                                                  \
             else {                                             \
                 if (allow_customConnection) {                  \
@@ -439,16 +449,16 @@ do {                                                           \
                      know if this connection has an            \
                      associated file                           \
                      */                                        \
-                    INCREMENT_NAMED_defineVar(errcndSymbol , ThisPathUnrecognizedConnectionClassError(R_NilValue, Rcon_or_summary), documentcontext);\
-                    INCREMENT_NAMED_defineVar(for_msgSymbol, ScalarString(description)                                            , documentcontext);\
+                    INCREMENT_NAMED_defineVar(errcndSymbol , UnrecognizedConnectionClassError, documentcontext);\
+                    INCREMENT_NAMED_defineVar(for_msgSymbol, Rf_ScalarString(description)    , documentcontext);\
                 }                                              \
                 else                                           \
-                    errorcall(call, "invalid '%s', cannot be a connection of class '%s'",\
-                        EncodeChar(PRINTNAME(sym)), EncodeChar(mkChar(klass)));\
+                    Rf_errorcall(call, "invalid '%s', cannot be a connection of class '%s'",\
+                        EncodeChar(PRINTNAME(sym)), EncodeChar(Rf_mkChar(klass)));\
             }                                                  \
         }                                                      \
         if (assign_returnvalue) {                              \
-            returnvalue = PROTECT(ofile); nprotect++;          \
+            returnvalue = Rf_protect(ofile); nprotect++;       \
         }                                                      \
     }                                                          \
     if (documentcontext != R_EmptyEnv) {                       \
@@ -459,10 +469,10 @@ do {                                                           \
             INCREMENT_NAMED_defineVar(documentcontextSymbol, documentcontext, assign_here);\
             R_LockBinding(documentcontextSymbol, assign_here); \
         } else {                                               \
-            setAttrib(assign_here, documentcontextSymbol, documentcontext);\
+            Rf_setAttrib(assign_here, documentcontextSymbol, documentcontext);\
         }                                                      \
     }                                                          \
-    UNPROTECT(nprotect);                                       \
+    Rf_unprotect(nprotect);                                    \
 } while (0)
 
 
